==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractFieldNodeTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractFieldNodeTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Title title;
	public _96_1_0706228950 _96_1_0706228950;
	public FieldNodeTemplate._96_1_0706228950. _97_2_0300442098 _97_2_0300442098;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. EmptyBlock emptyBlock;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _99_4_0992508185 _99_4_0992508185;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _100_4_1401232569 _100_4_1401232569;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. AddType addType;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. SelectType selectType;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. OpenNodeTrigger openNodeTrigger;
	public SelectNodeTypeDialog selectNodeTypeDialog;
	public FieldNodeTemplate.SelectNodeTypeDialog. NodeTypeSeletor nodeTypeSeletor;
	public NodeDialog nodeDialog;
	public FieldNodeTemplate.NodeDialog. _109_2_02064387320 _109_2_02064387320;
	public FieldNodeTemplate.NodeDialog._109_2_02064387320. NodeFrame nodeFrame;

    public AbstractFieldNodeTemplate(B box) {
        super(box);
        id("fieldNodeTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (title == null) title = register(new Title(box()).<Title>id("a782578768").owner(AbstractFieldNodeTemplate.this));
		if (_96_1_0706228950 == null) _96_1_0706228950 = register(new _96_1_0706228950(box()).<_96_1_0706228950>id("a1326751650").owner(AbstractFieldNodeTemplate.this));
		if (_96_1_0706228950 != null) _97_2_0300442098 = _96_1_0706228950._97_2_0300442098;
		if (_97_2_0300442098 != null) emptyBlock = _96_1_0706228950._97_2_0300442098.emptyBlock;
		if (emptyBlock != null) _99_4_0992508185 = _96_1_0706228950._97_2_0300442098.emptyBlock._99_4_0992508185;
		if (emptyBlock != null) _100_4_1401232569 = _96_1_0706228950._97_2_0300442098.emptyBlock._100_4_1401232569;
		if (_100_4_1401232569 != null) addType = _96_1_0706228950._97_2_0300442098.emptyBlock._100_4_1401232569.addType;
		if (_100_4_1401232569 != null) selectType = _96_1_0706228950._97_2_0300442098.emptyBlock._100_4_1401232569.selectType;
		if (_97_2_0300442098 != null) openNodeTrigger = _96_1_0706228950._97_2_0300442098.openNodeTrigger;
		if (selectNodeTypeDialog == null) selectNodeTypeDialog = register(new SelectNodeTypeDialog(box()).<SelectNodeTypeDialog>id("a_1309250584").owner(AbstractFieldNodeTemplate.this));
		if (selectNodeTypeDialog != null) nodeTypeSeletor = selectNodeTypeDialog.nodeTypeSeletor;
		if (nodeDialog == null) nodeDialog = register(new NodeDialog(box()).<NodeDialog>id("a304609010").owner(AbstractFieldNodeTemplate.this));
		if (nodeDialog != null) _109_2_02064387320 = nodeDialog._109_2_02064387320;
		if (_109_2_02064387320 != null) nodeFrame = nodeDialog._109_2_02064387320.nodeFrame;




		if (selectType != null) selectType.bindTo(selectNodeTypeDialog);
		if (openNodeTrigger != null) openNodeTrigger.bindTo(nodeDialog);
		if (selectNodeTypeDialog != null) selectNodeTypeDialog.bindTo(nodeTypeSeletor);
	}

	public class Title extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Title(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _96_1_0706228950 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public FieldNodeTemplate._96_1_0706228950. _97_2_0300442098 _97_2_0300442098;

		public _96_1_0706228950(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_97_2_0300442098 == null) _97_2_0300442098 = register(new _97_2_0300442098(box()).<_97_2_0300442098>id("a_2076804884").owner(AbstractFieldNodeTemplate.this));
		}

		public class _97_2_0300442098 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. EmptyBlock emptyBlock;
			public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. OpenNodeTrigger openNodeTrigger;

			public _97_2_0300442098(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (emptyBlock == null) emptyBlock = register(new EmptyBlock(box()).<EmptyBlock>id("a_675895269").owner(AbstractFieldNodeTemplate.this));
				if (openNodeTrigger == null) openNodeTrigger = register(new OpenNodeTrigger(box()).<OpenNodeTrigger>id("a1453435057").owner(AbstractFieldNodeTemplate.this));
			}

			public class EmptyBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _99_4_0992508185 _99_4_0992508185;
				public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _100_4_1401232569 _100_4_1401232569;

				public EmptyBlock(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_99_4_0992508185 == null) _99_4_0992508185 = register(new _99_4_0992508185(box()).<_99_4_0992508185>id("a722976578").owner(AbstractFieldNodeTemplate.this));
					if (_100_4_1401232569 == null) _100_4_1401232569 = register(new _100_4_1401232569(box()).<_100_4_1401232569>id("a2117158431").owner(AbstractFieldNodeTemplate.this));
				}

				public class _99_4_0992508185 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _99_4_0992508185(B box) {
						super(box);
						_value("No element defined");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class _100_4_1401232569 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. AddType addType;
					public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. SelectType selectType;

					public _100_4_1401232569(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (addType == null) addType = register(new AddType(box()).<AddType>id("a_503568369").owner(AbstractFieldNodeTemplate.this));
						if (selectType == null) selectType = register(new SelectType(box()).<SelectType>id("a2099461442").owner(AbstractFieldNodeTemplate.this));
					}

					public class AddType extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

						public AddType(B box) {
							super(box);
							_title("Add element");
							_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
						}

						@Override
						public void init() {
							super.init();
						}
					}

					public class SelectType extends io.intino.alexandria.ui.displays.components.OpenDialog<io.intino.alexandria.ui.displays.notifiers.OpenDialogNotifier, B>  {

						public SelectType(B box) {
							super(box);
							_title("Add element");
							_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
						}

						@Override
						public void init() {
							super.init();
						}
					}
				}
			}

			public class OpenNodeTrigger extends io.intino.alexandria.ui.displays.components.OpenDialog<io.intino.alexandria.ui.displays.notifiers.OpenDialogNotifier, B>  {

				public OpenNodeTrigger(B box) {
					super(box);
					_title("Open");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}

	public class SelectNodeTypeDialog extends io.intino.alexandria.ui.displays.components.DecisionDialog<io.intino.alexandria.ui.displays.notifiers.DecisionDialogNotifier, B>  {
		public FieldNodeTemplate.SelectNodeTypeDialog. NodeTypeSeletor nodeTypeSeletor;

		public SelectNodeTypeDialog(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nodeTypeSeletor == null) nodeTypeSeletor = register(new NodeTypeSeletor(box()).<NodeTypeSeletor>id("a_1724746791").owner(AbstractFieldNodeTemplate.this));
		}

		public class NodeTypeSeletor extends io.intino.alexandria.ui.displays.components.SelectorListBox<io.intino.alexandria.ui.displays.notifiers.SelectorListBoxNotifier, B>  {

			public NodeTypeSeletor(B box) {
				super(box);
				_multipleSelection(false);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class NodeDialog extends io.intino.alexandria.ui.displays.components.Dialog<io.intino.alexandria.ui.displays.notifiers.DialogNotifier, B>  {
		public FieldNodeTemplate.NodeDialog. _109_2_02064387320 _109_2_02064387320;

		public NodeDialog(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_109_2_02064387320 == null) _109_2_02064387320 = register(new _109_2_02064387320(box()).<_109_2_02064387320>id("a_2048699257").owner(AbstractFieldNodeTemplate.this));
		}

		public class _109_2_02064387320 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public FieldNodeTemplate.NodeDialog._109_2_02064387320. NodeFrame nodeFrame;

			public _109_2_02064387320(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (nodeFrame == null) nodeFrame = register(new NodeFrame(box()).<NodeFrame>id("a_1530961626").owner(AbstractFieldNodeTemplate.this));
			}

			public class NodeFrame extends io.intino.alexandria.ui.displays.components.DisplayStamp<io.intino.alexandria.ui.displays.notifiers.DisplayStampNotifier, B>  {

				public NodeFrame(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractFieldNodeTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractFieldNodeTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Title title;
	public _96_1_0706228950 _96_1_0706228950;
	public FieldNodeTemplate._96_1_0706228950. _97_2_0300442098 _97_2_0300442098;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. EmptyBlock emptyBlock;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _99_4_0992508185 _99_4_0992508185;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _100_4_1401232569 _100_4_1401232569;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. AddType addType;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. SelectType selectType;
	public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. OpenNodeTrigger openNodeTrigger;
	public SelectNodeTypeDialog selectNodeTypeDialog;
	public FieldNodeTemplate.SelectNodeTypeDialog. NodeTypeSeletor nodeTypeSeletor;
	public NodeDialog nodeDialog;
	public FieldNodeTemplate.NodeDialog. _109_2_02064387320 _109_2_02064387320;
	public FieldNodeTemplate.NodeDialog._109_2_02064387320. NodeFrame nodeFrame;

    public AbstractFieldNodeTemplate(B box) {
        super(box);
        id("fieldNodeTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (title == null) title = register(new Title(box()).<Title>id("a782578768").owner(AbstractFieldNodeTemplate.this));
		if (_96_1_0706228950 == null) _96_1_0706228950 = register(new _96_1_0706228950(box()).<_96_1_0706228950>id("a1326751650").owner(AbstractFieldNodeTemplate.this));
		if (_96_1_0706228950 != null) _97_2_0300442098 = _96_1_0706228950._97_2_0300442098;
		if (_97_2_0300442098 != null) emptyBlock = _96_1_0706228950._97_2_0300442098.emptyBlock;
		if (emptyBlock != null) _99_4_0992508185 = _96_1_0706228950._97_2_0300442098.emptyBlock._99_4_0992508185;
		if (emptyBlock != null) _100_4_1401232569 = _96_1_0706228950._97_2_0300442098.emptyBlock._100_4_1401232569;
		if (_100_4_1401232569 != null) addType = _96_1_0706228950._97_2_0300442098.emptyBlock._100_4_1401232569.addType;
		if (_100_4_1401232569 != null) selectType = _96_1_0706228950._97_2_0300442098.emptyBlock._100_4_1401232569.selectType;
		if (_97_2_0300442098 != null) openNodeTrigger = _96_1_0706228950._97_2_0300442098.openNodeTrigger;
		if (selectNodeTypeDialog == null) selectNodeTypeDialog = register(new SelectNodeTypeDialog(box()).<SelectNodeTypeDialog>id("a_1309250584").owner(AbstractFieldNodeTemplate.this));
		if (selectNodeTypeDialog != null) nodeTypeSeletor = selectNodeTypeDialog.nodeTypeSeletor;
		if (nodeDialog == null) nodeDialog = register(new NodeDialog(box()).<NodeDialog>id("a304609010").owner(AbstractFieldNodeTemplate.this));
		if (nodeDialog != null) _109_2_02064387320 = nodeDialog._109_2_02064387320;
		if (_109_2_02064387320 != null) nodeFrame = nodeDialog._109_2_02064387320.nodeFrame;




		if (selectType != null) selectType.bindTo(selectNodeTypeDialog);
		if (openNodeTrigger != null) openNodeTrigger.bindTo(nodeDialog);
		if (selectNodeTypeDialog != null) selectNodeTypeDialog.bindTo(nodeTypeSeletor);
	}

    @Override
    public void remove() {
        super.remove();
	    if (title != null) title.unregister();
	    if (_96_1_0706228950 != null) _96_1_0706228950.unregister();
	    if (selectNodeTypeDialog != null) selectNodeTypeDialog.unregister();
	    if (nodeDialog != null) nodeDialog.unregister();
	}

	public class Title extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Title(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class _96_1_0706228950 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public FieldNodeTemplate._96_1_0706228950. _97_2_0300442098 _97_2_0300442098;

		public _96_1_0706228950(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_97_2_0300442098 == null) _97_2_0300442098 = register(new _97_2_0300442098(box()).<_97_2_0300442098>id("a_2076804884").owner(AbstractFieldNodeTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_97_2_0300442098 != null) _97_2_0300442098.unregister();
		}

		public class _97_2_0300442098 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. EmptyBlock emptyBlock;
			public FieldNodeTemplate._96_1_0706228950._97_2_0300442098. OpenNodeTrigger openNodeTrigger;

			public _97_2_0300442098(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (emptyBlock == null) emptyBlock = register(new EmptyBlock(box()).<EmptyBlock>id("a_675895269").owner(AbstractFieldNodeTemplate.this));
				if (openNodeTrigger == null) openNodeTrigger = register(new OpenNodeTrigger(box()).<OpenNodeTrigger>id("a1453435057").owner(AbstractFieldNodeTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (emptyBlock != null) emptyBlock.unregister();
				if (openNodeTrigger != null) openNodeTrigger.unregister();
			}

			public class EmptyBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _99_4_0992508185 _99_4_0992508185;
				public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock. _100_4_1401232569 _100_4_1401232569;

				public EmptyBlock(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_99_4_0992508185 == null) _99_4_0992508185 = register(new _99_4_0992508185(box()).<_99_4_0992508185>id("a722976578").owner(AbstractFieldNodeTemplate.this));
					if (_100_4_1401232569 == null) _100_4_1401232569 = register(new _100_4_1401232569(box()).<_100_4_1401232569>id("a2117158431").owner(AbstractFieldNodeTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_99_4_0992508185 != null) _99_4_0992508185.unregister();
					if (_100_4_1401232569 != null) _100_4_1401232569.unregister();
				}

				public class _99_4_0992508185 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _99_4_0992508185(B box) {
						super(box);
						_value("No element defined");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class _100_4_1401232569 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. AddType addType;
					public FieldNodeTemplate._96_1_0706228950._97_2_0300442098.EmptyBlock._100_4_1401232569. SelectType selectType;

					public _100_4_1401232569(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (addType == null) addType = register(new AddType(box()).<AddType>id("a_503568369").owner(AbstractFieldNodeTemplate.this));
						if (selectType == null) selectType = register(new SelectType(box()).<SelectType>id("a2099461442").owner(AbstractFieldNodeTemplate.this));
					}

					@Override
					public void unregister() {
					    super.unregister();
						if (addType != null) addType.unregister();
						if (selectType != null) selectType.unregister();
					}

					public class AddType extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

						public AddType(B box) {
							super(box);
							_title("Add element");
							_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public void unregister() {
						    super.unregister();
						}
					}

					public class SelectType extends io.intino.alexandria.ui.displays.components.OpenDialog<io.intino.alexandria.ui.displays.notifiers.OpenDialogNotifier, B>  {

						public SelectType(B box) {
							super(box);
							_title("Add element");
							_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public void unregister() {
						    super.unregister();
						}
					}
				}
			}

			public class OpenNodeTrigger extends io.intino.alexandria.ui.displays.components.OpenDialog<io.intino.alexandria.ui.displays.notifiers.OpenDialogNotifier, B>  {

				public OpenNodeTrigger(B box) {
					super(box);
					_title("Open");
					_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}

	public class SelectNodeTypeDialog extends io.intino.alexandria.ui.displays.components.DecisionDialog<io.intino.alexandria.ui.displays.notifiers.DecisionDialogNotifier, B>  {
		public FieldNodeTemplate.SelectNodeTypeDialog. NodeTypeSeletor nodeTypeSeletor;

		public SelectNodeTypeDialog(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (nodeTypeSeletor == null) nodeTypeSeletor = register(new NodeTypeSeletor(box()).<NodeTypeSeletor>id("a_1724746791").owner(AbstractFieldNodeTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (nodeTypeSeletor != null) nodeTypeSeletor.unregister();
		}

		public class NodeTypeSeletor extends io.intino.alexandria.ui.displays.components.SelectorListBox<io.intino.alexandria.ui.displays.notifiers.SelectorListBoxNotifier, B>  {

			public NodeTypeSeletor(B box) {
				super(box);
				_multipleSelection(false);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class NodeDialog extends io.intino.alexandria.ui.displays.components.Dialog<io.intino.alexandria.ui.displays.notifiers.DialogNotifier, B>  {
		public FieldNodeTemplate.NodeDialog. _109_2_02064387320 _109_2_02064387320;

		public NodeDialog(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_109_2_02064387320 == null) _109_2_02064387320 = register(new _109_2_02064387320(box()).<_109_2_02064387320>id("a_2048699257").owner(AbstractFieldNodeTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_109_2_02064387320 != null) _109_2_02064387320.unregister();
		}

		public class _109_2_02064387320 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public FieldNodeTemplate.NodeDialog._109_2_02064387320. NodeFrame nodeFrame;

			public _109_2_02064387320(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (nodeFrame == null) nodeFrame = register(new NodeFrame(box()).<NodeFrame>id("a_1530961626").owner(AbstractFieldNodeTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (nodeFrame != null) nodeFrame.unregister();
			}

			public class NodeFrame extends io.intino.alexandria.ui.displays.components.DisplayStamp<io.intino.alexandria.ui.displays.notifiers.DisplayStampNotifier, B>  {

				public NodeFrame(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}
}
